@@ -1,7 +1,7 @@
 #!/bin/sh
 
 PACKAGE=indent
-INFODIR=/usr/info
+INFODIR=/usr/share/info
 INSTALLINFO=/usr/bin/install-info
 
 if [ -x ${INSTALLINFO} -a -f ${INFODIR}/${PACKAGE}.info ] ; then
